@@ -6,28 +6,24 @@ from aparnik.utils.utils import convert_iran_phone_number_to_world_number
 from ..models import ContactUs
 
 
-class ContactUsDestailSerializer(ModelSerializer):
+class ContactUsListSerializer(ModelSerializer):
     url = serializers.SerializerMethodField()
-    phone = serializers.CharField(required=False)
+    resourcetype = serializers.SerializerMethodField()
 
     def __init__(self, *args, **kwargs):
-        super(ContactUsDestailSerializer, self).__init__(*args, **kwargs)
+        super(ContactUsListSerializer, self).__init__(*args, **kwargs)
 
     class Meta:
         model = ContactUs
         fields = [
             'id',
             'url',
-            'website',
-            'address',
-            'phone',
-            'email',
             'first_name',
             'last_name',
             'title',
-            'content',
             'is_active',
             'update_at',
+            'resourcetype',
         ]
 
         read_only_fields = [
@@ -35,10 +31,34 @@ class ContactUsDestailSerializer(ModelSerializer):
             'url',
             'is_active',
             'update_at',
+            'resourcetype',
         ]
 
     def get_url(self, obj):
         return self.context['request'].build_absolute_uri(obj.get_api_uri())
 
+    def get_resourcetype(self, obj):
+        return 'ContactUs'
+
+
+class ContactUsDestailSerializer(ContactUsListSerializer):
+    phone = serializers.CharField(required=False)
+
+    def __init__(self, *args, **kwargs):
+        super(ContactUsDestailSerializer, self).__init__(*args, **kwargs)
+
+    class Meta:
+        model = ContactUs
+        fields = ContactUsListSerializer.Meta.fields + [
+            'website',
+            'address',
+            'phone',
+            'email',
+            'content',
+        ]
+
+        read_only_fields = ContactUsListSerializer.Meta.read_only_fields + [
+        ]
+
     def validate_phone(self, value):
         return convert_iran_phone_number_to_world_number(value)
